@@ -9,12 +9,13 @@ Created on Sun May 19 12:21:06 2019
 from SigProfilerExtractor import subroutines as sub
 import numpy as np
 import pandas as pd
+import SigProfilerExtractor as cosmic
 import os
 
 
 
 
-def decompose(signatures, activities, samples, output, nnls_add_penalty=0.05, nnls_remove_penalty=0.01, initial_remove_penalty=0.05, genome_build="GRCh37", refit_denovo_signatures=True, verbose=False):
+def decompose(signatures, activities, samples, output, nnls_add_penalty=0.05, nnls_remove_penalty=0.01, initial_remove_penalty=0.05, genome_build="GRCh37", refit_denovo_signatures=True, make_decomposition_plots=True, connected_sigs=True, verbose=False):
 
     
     """
@@ -66,7 +67,7 @@ def decompose(signatures, activities, samples, output, nnls_add_penalty=0.05, nn
     
     
     
-    processAvg = np.array(processAvg)
+    
     
     
     
@@ -76,9 +77,17 @@ def decompose(signatures, activities, samples, output, nnls_add_penalty=0.05, nn
         mutation_context = "DBS78"
     elif mutation_type == "83":
         mutation_context = "ID83"
+    elif mutation_type=="48":
+        mutation_context = "CNV48"
+        print("Mutation Type is: CNV")
+        paths = cosmic.__path__[0]
+        sigDatabase = pd.read_csv(paths+"/data/CNV_signatures.txt", sep="\t",index_col=0)
+        genomes=genomes.loc[sigDatabase.index]
+        processAvg=processAvg.loc[sigDatabase.index]
     else:
         mutation_context = "SBS"+mutation_type
         
+    processAvg = np.array(processAvg)    
     signature_names = sub.make_letter_ids(idlenth = processAvg.shape[1], mtype = mutation_context)
     exposureAvg.columns=signature_names   
     
@@ -111,13 +120,10 @@ def decompose(signatures, activities, samples, output, nnls_add_penalty=0.05, nn
     genomes = pd.DataFrame(genomes)
     
     
-    if refit_denovo_signatures==True:
-        denovo_exposureAvg="none"
-    else:
-        denovo_exposureAvg = np.array(exposureAvg)
-    
-    exposureAvg = sub.make_final_solution(processAvg, genomes, listOfSignatures, layer_directory1, m, index, \
-                   colnames,denovo_exposureAvg  = denovo_exposureAvg, add_penalty=nnls_add_penalty, remove_penalty=nnls_remove_penalty, initial_remove_penalty=initial_remove_penalty)    
+   
+    denovo_exposureAvg = np.array(exposureAvg.T)
+    exposureAvg = sub.make_final_solution(processAvg, genomes, listOfSignatures, layer_directory1, m, index,\
+                   colnames,denovo_exposureAvg  = denovo_exposureAvg, add_penalty=nnls_add_penalty, remove_penalty=nnls_remove_penalty, initial_remove_penalty=initial_remove_penalty, connected_sigs=connected_sigs, refit_denovo_signatures=refit_denovo_signatures)    
 
     
     
@@ -145,7 +151,7 @@ def decompose(signatures, activities, samples, output, nnls_add_penalty=0.05, nn
         processAvg = np.array(processAvg)
             
     
-    final_signatures = sub.signature_decomposition(processAvg, m, layer_directory2, genome_build=genome_build, mutation_context=mutation_context, add_penalty=nnls_add_penalty, remove_penalty=nnls_remove_penalty)    
+    final_signatures = sub.signature_decomposition(processAvg, m, layer_directory2, genome_build=genome_build, mutation_context=mutation_context, add_penalty=nnls_add_penalty, connected_sigs=connected_sigs,remove_penalty=nnls_remove_penalty, make_decomposition_plots=make_decomposition_plots)    
     #final_signatures = sub.signature_decomposition(processAvg, m, layer_directory2, genome_build=genome_build)
     # extract the global signatures and new signatures from the final_signatures dictionary
     globalsigs = final_signatures["globalsigs"]
@@ -162,7 +168,7 @@ def decompose(signatures, activities, samples, output, nnls_add_penalty=0.05, nn
     
     
     result = sub.make_final_solution(processAvg, genomes, allsigids, layer_directory2, m, index, colnames, \
-                            remove_sigs=True, attribution = attribution, denovo_exposureAvg  = exposureAvg ,  background_sigs=background_sigs, verbose=verbose, genome_build=genome_build, add_penalty=nnls_add_penalty, remove_penalty=nnls_remove_penalty, initial_remove_penalty=initial_remove_penalty)
+                            cosmic_sigs=True, attribution = attribution, denovo_exposureAvg  = exposureAvg ,  background_sigs=background_sigs, verbose=verbose, genome_build=genome_build, add_penalty=nnls_add_penalty, remove_penalty=nnls_remove_penalty, initial_remove_penalty=initial_remove_penalty,connected_sigs=connected_sigs,refit_denovo_signatures=False)
 
     return result
 
